(function (factory) {
  if (typeof module === "object" && typeof module.exports === "object") {
    var v = factory(require, exports);
    if (v !== undefined) module.exports = v;
  } else if (typeof define === "function" && define.amd) {
    define(["require", "exports", "path", "@spicypixel/core-kit-js"], factory);
  }
})(function (require, exports) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  const path = require("path");

  const CoreKit = require("@spicypixel/core-kit-js");

  class UnityModuleLibraryReference {
    constructor(module, nodeModule) {
      this._module = module;
      this._nodeModule = nodeModule;
    }

    get installPath() {
      return this._module.modulePath;
    }
    /** Update module with latest library */


    async installAsync(assemblyNames, editorAssemblyNames, sourceNames, editorSourceNames) {
      await this.uninstallAsync();
      await this.copyLibraryToAssetsAsync(assemblyNames, editorAssemblyNames, sourceNames, editorSourceNames);
    }

    async uninstallAsync() {
      // Remove files except *.meta
      await CoreKit.FileSystem.removePatternsAsync(["Docs/**/*", "Editor/**/*", "Lib/**/*", "MonoDoc/**/*", "Scripts/**/*", "README.md", "LICENSE.md", "!**/*.meta"], {
        cwd: this.installPath,
        nodir: true
      }); // Remove folders that no longer exist

      await CoreKit.FileSystem.Directory.removeUnmatchedAsync(path.join(this._nodeModule.packageDir, "Docs"), path.join(this.installPath, "Docs"), {
        ignoreMissingSource: true,
        ignoreMissingDestination: true
      });
      await CoreKit.FileSystem.Directory.removeUnmatchedAsync(path.join(this._nodeModule.packageDir, "Source"), path.join(this.installPath, "Scripts"), {
        ignoreMissingSource: true,
        ignoreMissingDestination: true
      });
      await CoreKit.FileSystem.Directory.removeUnmatchedAsync(path.join(this._nodeModule.packageDir, "Source"), path.join(this.installPath, "Editor"), {
        ignoreMissingSource: true,
        ignoreMissingDestination: true
      });
    }

    async copyLibraryToAssetsAsync(assemblyNames, editorAssemblyNames, sourceNames, editorSourceNames) {
      const docsSrcDir = path.join(this._nodeModule.packageDir, "Docs");
      const sourceSrcDir = path.join(this._nodeModule.packageDir, "Source");
      const docsDestDir = path.join(this.installPath, "Docs");
      const monoDocDestDir = path.join(this.installPath, "MonoDoc");
      const libDestDir = path.join(this.installPath, "Lib");
      const editorDestDir = path.join(this.installPath, "Editor");
      const sourceDestDir = path.join(this.installPath, "Scripts");
      let promises = [];
      assemblyNames.forEach(assembly => {
        const srcDir = path.join(sourceSrcDir, assembly, "bin", "Release");
        promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync(path.join(srcDir, assembly + ".dll"), libDestDir, {
          base: srcDir
        }));
      });
      if (!editorAssemblyNames) editorAssemblyNames = [];
      editorAssemblyNames.forEach(assembly => {
        const srcDir = path.join(sourceSrcDir, assembly, "bin", "Release");
        promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync(path.join(srcDir, assembly + ".dll"), editorDestDir, {
          base: srcDir
        }));
      });
      if (!sourceNames) sourceNames = [];
      sourceNames.forEach(assembly => {
        const srcDir = path.join(sourceSrcDir, assembly);
        promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync([path.join(srcDir, "**", "*.cs"), "!" + path.join(srcDir, "**", "AssemblyInfo.cs")], sourceDestDir, {
          base: sourceSrcDir
        }));
      });
      if (!editorSourceNames) editorSourceNames = [];
      editorSourceNames.forEach(assembly => {
        const srcDir = path.join(sourceSrcDir, assembly);
        promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync([path.join(srcDir, "**", "*.cs"), "!" + path.join(srcDir, "**", "AssemblyInfo.cs")], editorDestDir, {
          base: sourceSrcDir
        }));
      });
      promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync(path.join(docsSrcDir, "**/*"), docsDestDir, {
        base: docsSrcDir
      }));
      promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync(["*.source", "assemble/*.tree", "assemble/*.zip"], monoDocDestDir, {
        cwd: path.join(this._nodeModule.packageDir, "MonoDoc"),
        flatten: true
      }));
      promises = promises.concat(CoreKit.FileSystem.copyPatternsAsync(["README.md", "LICENSE.md"], this.installPath, {
        cwd: this._nodeModule.packageDir
      }));
      await Promise.all(promises);
    }

  }

  exports.default = UnityModuleLibraryReference;
});
//# sourceMappingURL=unity-module-library-reference.js.map
