(function (factory) {
  if (typeof module === "object" && typeof module.exports === "object") {
    var v = factory(require, exports);
    if (v !== undefined) module.exports = v;
  } else if (typeof define === "function" && define.amd) {
    define(["require", "exports", "path", "@spicypixel/core-kit-js", "./unity-project"], factory);
  }
})(function (require, exports) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  const path = require("path");

  const CoreKit = require("@spicypixel/core-kit-js");

  const unity_project_1 = require("./unity-project");

  class UnityModuleReference {
    constructor(module, nodeModule, nodeModuleVendor, nodeModuleName) {
      this._module = module;
      this._nodeModule = nodeModule;
      this._nodeModuleVendor = nodeModuleVendor;
      this._nodeModuleName = nodeModuleName;
      this._nodeModuleProject = new unity_project_1.default(nodeModule.packageDir);
    }

    get referencePath() {
      return path.resolve(path.join(this._nodeModuleProject.assetsPath, this._nodeModuleVendor, "Modules", this._nodeModuleName));
    }

    get installPath() {
      return path.resolve(path.join(this._module.project.assetsPath, this._nodeModuleVendor, "Modules", this._nodeModuleName));
    }

    get artifactsPath() {
      return path.join(this._nodeModuleProject.projectPath, "Artifacts");
    }

    async installAsync() {
      if (this.referencePath === this.installPath) {
        throw new Error("Source and destination cannot be the same: " + this.referencePath);
      }

      await this.uninstallAsync(); // Installing using the package would load Unity
      // and package import would fail because scripts that
      // depend on the package wouldn't find it yet.
      //
      // Launching Unity will also trigger a scan and
      // remove any .metas for files that are not present.
      //
      // Perform a file system copy instead.
      // const packageFileName = await this.getPackageFileName();
      // await this._module.project.importPackageAsync(path.join(this.artifactsPath, packageFileName));

      CoreKit.FileSystem.copyPatternsAsync(path.join(this.referencePath, "**", "*"), this.installPath);
      CoreKit.FileSystem.File.copyAsync(this.referencePath + ".meta", this.installPath + ".meta");
    }

    async uninstallAsync() {
      await CoreKit.FileSystem.removePatternsAsync(path.join(this.installPath, "*")); // Remove files except *.meta
      // await CoreKit.FileSystem.removePatternsAsync([
      //   "**/*",
      //   "!**/*.meta"
      // ], { cwd: this.installPath, nodir: true });
      // Remove folders that no longer exist
      // await CoreKit.FileSystem.Directory.removeUnmatchedAsync(
      //   this.referencePath,
      //   this.installPath,
      //   { ignoreMissingSource: true, ignoreMissingDestination: true }
      // );
    }

    async getPackageFileName() {
      const pkg = await CoreKit.FileSystem.File.readFileAsync(path.join(this._nodeModuleProject.projectPath, "package.json"), "utf8");
      const tag = "v" + JSON.parse(pkg).version;
      return this._nodeModuleVendor + "." + this._nodeModuleName + "-" + tag + ".unitypackage";
    }

  }

  exports.default = UnityModuleReference;
});
//# sourceMappingURL=unity-module-reference.js.map
