(function (factory) {
  if (typeof module === "object" && typeof module.exports === "object") {
    var v = factory(require, exports);
    if (v !== undefined) module.exports = v;
  } else if (typeof define === "function" && define.amd) {
    define(["require", "exports", "gulp-util", "path", "@spicypixel/core-kit-js", "./unity-project"], factory);
  }
})(function (require, exports) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  const gutil = require("gulp-util");

  const path = require("path");

  const CoreKit = require("@spicypixel/core-kit-js");

  const unity_project_1 = require("./unity-project");

  class UnityModule {
    constructor(project, vendor, name) {
      this._project = project;
      this._vendor = vendor;
      this._name = name;
    }

    static createFromPath(path, vendor, name) {
      return new UnityModule(new unity_project_1.default(path), vendor, name);
    }

    static createFromProject(unityProject, vendor, name) {
      return new UnityModule(unityProject, vendor, name);
    }

    get project() {
      return this._project;
    }

    get vendor() {
      return this._vendor;
    }

    get name() {
      return this._name;
    }

    get modulePath() {
      return path.join(this._project.assetsPath, this._vendor, "Modules", this._name);
    }

    get artifactsPath() {
      return path.join(this._project.projectPath, "Artifacts");
    }

    async getPackageFileName() {
      const pkg = await CoreKit.FileSystem.File.readFileAsync(path.join(this._project.projectPath, "package.json"), "utf8");
      const tag = "v" + JSON.parse(pkg).version;
      return this._vendor + "." + this._name + "-" + tag + ".unitypackage";
    }

    async exportPackageAsync() {
      try {
        await CoreKit.FileSystem.Directory.accessAsync(this.modulePath, CoreKit.FileSystem.FileSystemPermission.Visible);
      } catch (err) {
        gutil.log("Skipping export Unity package because module folder does not exist: ", this.modulePath);
        return;
      }

      await CoreKit.FileSystem.Directory.createRecursiveAsync(this.artifactsPath);
      await this.cleanArtifactsAsync();
      const packageFileName = await this.getPackageFileName();
      await this._project.exportPackageAsync([path.relative(this._project.projectPath, this.modulePath)], path.join(this.artifactsPath, packageFileName));
    }

    async cleanArtifactsAsync() {
      await CoreKit.FileSystem.removePatternsAsync(path.join(this.artifactsPath, "*"));
    }

  }

  exports.default = UnityModule;
});
//# sourceMappingURL=unity-module.js.map
