(function (factory) {
  if (typeof module === "object" && typeof module.exports === "object") {
    var v = factory(require, exports);
    if (v !== undefined) module.exports = v;
  } else if (typeof define === "function" && define.amd) {
    define(["require", "exports", "path", "@spicypixel/core-kit-js/lib/file-system", "@spicypixel/core-kit-js/lib/child-process", "./unity-editor"], factory);
  }
})(function (require, exports) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  const path = require("path");

  const fs = require("@spicypixel/core-kit-js/lib/file-system");

  const child_process_1 = require("@spicypixel/core-kit-js/lib/child-process");

  const unity_editor_1 = require("./unity-editor");

  const spawnOptions = {
    silentUntilError: true
  };

  class UnityProject {
    constructor(projectPath) {
      this._projectPath = projectPath;
    }

    get projectPath() {
      return this._projectPath;
    }

    get assetsPath() {
      return path.join(this._projectPath, "Assets");
    }

    get projectPathArgs() {
      return ["-projectPath", this._projectPath];
    }

    async createAsync() {
      await fs.Directory.createRecursiveAsync(path.dirname(this._projectPath));
      let args = unity_editor_1.default.batchModeArgs;
      args = args.concat("-createProject");
      args = args.concat(this._projectPath);
      await child_process_1.default.spawnAsync(unity_editor_1.default.editorPath, args, spawnOptions);
    }

    async exportPackageAsync(sourcePaths, outputPath) {
      await this.verifyProjectExistsAsync();
      await fs.Directory.createRecursiveAsync(path.dirname(outputPath));
      let args = unity_editor_1.default.batchModeArgs;
      args = args.concat(this.projectPathArgs);
      args = args.concat("-exportPackage");
      args = args.concat(sourcePaths);
      args = args.concat(outputPath);
      await child_process_1.default.spawnAsync(unity_editor_1.default.editorPath, args, spawnOptions);
    }

    async importPackageAsync(packagePath) {
      await this.verifyProjectExistsAsync();
      if (!path.isAbsolute(packagePath)) packagePath = path.resolve(path.join(this._projectPath, packagePath));

      try {
        await fs.FileSystemRecord.accessAsync(packagePath, fs.FileSystemPermission.Visible);
      } catch (err) {
        throw new Error("Package path does not exist: " + err.message);
      }

      let args = unity_editor_1.default.batchModeArgs;
      args = args.concat(this.projectPathArgs);
      args = args.concat("-importPackage");
      args = args.concat(packagePath);
      await child_process_1.default.spawnAsync(unity_editor_1.default.editorPath, args, spawnOptions);
    }

    async verifyProjectExistsAsync() {
      try {
        await fs.FileSystemRecord.accessAsync(this._projectPath, fs.FileSystemPermission.Visible);
      } catch (err) {
        throw new Error("Project path does not exist: " + err.message);
      }
    }

  }

  exports.default = UnityProject;
});
//# sourceMappingURL=unity-project.js.map
